import * as cdk from "aws-cdk-lib";
import { Construct } from "constructs";
import { NodejsFunction } from "aws-cdk-lib/aws-lambda-nodejs";
import * as lambda from "aws-cdk-lib/aws-lambda";
import { CustomResource, Duration, RemovalPolicy } from "aws-cdk-lib";
import * as cr from "aws-cdk-lib/custom-resources";
import * as path from "path";

export class DummyLambdaStack extends cdk.Stack {
  constructor(scope: Construct, id: string, props?: cdk.StackProps) {
    super(scope, id, props);

    const onEventHandler = new NodejsFunction(this, "OnEventHandler", {
      runtime: lambda.Runtime.NODEJS_16_X,
      entry: path.join(__dirname, "./lambdas/on-event.js"),
      handler: "onEvent",
      timeout: Duration.seconds(10),
    });

    const provider = new cr.Provider(this, "Provider", {
      onEventHandler: onEventHandler,
    });

    [...Array(10)].forEach((_, i) => {
      new CustomResource(this, `CR${i}`, {
        serviceToken: provider.serviceToken,
        resourceType: "Custom::ProviderValue",
        removalPolicy: RemovalPolicy.DESTROY,
      });
    });
  }
}
